@@ -3,7 +3,8 @@
  *                                                                   
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
- *        Copyright (C) 1999, 2000, 2001, 2002, 2003 Henrik Sandklef                    
+ *        Copyright (C) 1999, 2000, 2001, 2002, 2003 
+ *                      2010 Henrik Sandklef                    
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -34,6 +35,20 @@
 int
 xnee_reset_fake( xnee_data *xd);
 
+
+#define xnee_fake_motion_event(xd, scr, x, y, dtime) xnee_fake_motion_event_impl(xd, scr, x, y, dtime, 0)
+
+#define xnee_fake_xi_motion_event(xd, scr, x, y, dtime, dev) xnee_fake_motion_event_impl(xd, scr, x, y, dtime, dev)
+
+#define xnee_fake_button_event(xd, button, bo , dtime)              xnee_fake_button_event_impl (xd, button, bo , dtime, 0) 
+
+#define xnee_fake_xi_button_event(xd, button, bo , dtime, deviceid) xnee_fake_button_event_impl (xd, button, bo , dtime, deviceid) 
+
+#define xnee_fake_key_event(xd, key, bo , dtime)              xnee_fake_key_event_impl (xd, key, bo , dtime, 0) 
+
+#define xnee_fake_xi_key_event(xd, key, bo , dtime, deviceid) xnee_fake_key_event_impl (xd, key, bo , dtime, deviceid) 
+
+
 /**
  * Sends a faked moton event to the display in the distribution list as found in xd.
  * @param xd       xnee's main structure
@@ -41,14 +56,17 @@ xnee_reset_fake( xnee_data *xd);
  * @param x        x coordinate
  * @param y        y coordinate
  * @param dtime    how long before the faking shall take place
+ * @param deviceid Id of the device (XInput extension)
  * @return int     XNEE_OK on success.
  */
 int 
-xnee_fake_motion_event (xnee_data* xd,
-			int screen, 
-			int x, 
-			int y, 
-			unsigned long dtime);
+xnee_fake_motion_event_impl (xnee_data* xd,
+			     int screen, 
+			     int x, 
+			     int y, 
+			     unsigned long dtime,
+			     int deviceid);
+
 
 
 /**
@@ -57,10 +75,15 @@ xnee_fake_motion_event (xnee_data* xd,
  * @param button   the button to fake
  * @param bo       press or release
  * @param dtime    how long before the faking shall take place
+ * @param deviceid Id of the device (XInput extension)
  * @return int     XNEE_OK on success.
  */
 int
-xnee_fake_button_event (xnee_data* xd, int button, Bool bo , int dtime);
+xnee_fake_button_event_impl (xnee_data* xd, 
+			     int button, 
+			     Bool bo , 
+			     int dtime,
+			     int deviceid);
 
 
 
@@ -70,10 +93,15 @@ xnee_fake_button_event (xnee_data* xd, int button, Bool bo , int dtime);
  * @param keycode  keycode of the event to be faked
  * @param bo       is it a press or a release
  * @param dtime    how long before the faking shall take place
+ * @param deviceid Id of the device (XInput extension)
  * @return int     XNEE_OK on success.
  */
 int 
-xnee_fake_key_event  (xnee_data* xd, int keycode, Bool bo, int dtime);
+xnee_fake_key_event_impl  (xnee_data* xd, 
+			   int  keycode, 
+			   Bool bo, 
+			   int  dtime,
+			   int  deviceid);
 
 
 /**
