@@ -44,6 +44,7 @@
 #include "libxnee/xnee_utils.h"
 #include "libxnee/xnee_window.h"
 #include "libxnee/xnee_range.h"
+#include "libxnee/xnee_xinput.h"
 
 static int time_out_counter = 0;
 static int diff_counter     = 0;
@@ -462,6 +463,7 @@ xnee_replay_main_loop(xnee_data *xd, int read_mode)
 			xnee_replay_event_handler(xd, 
 						  &xindata, 
 						  last_elapsed);
+		      xnee_verbose((xd," replayable :%d\n",replayable ));
 		      
 		    }
 		  else
@@ -513,7 +515,8 @@ xnee_replay_main_loop(xnee_data *xd, int read_mode)
 		    xnee_replay_event_handler(xd, 
 					      &xindata, 
 					      last_elapsed);
-		  
+		  xnee_verbose((xd," replayable :%d\n",replayable ));
+
 		  break;
 
 		default:
