@@ -156,7 +156,7 @@ xnee_calc_sleep_amount(xnee_data *xd,
   float start_diff_percent ;
   float compensation_factor ;
   float sleep_amt ; 
-  static stored_recordFirst_diff;
+  static unsigned long stored_recordFirst_diff;
 
   xnee_verbose ((xd, "xnee_calc_sleep_amount last_diff: %lu first_diff: %lu record_last_diff:" 
 		 "%lu recordFirst_diff: %lu\n",  
